Examples
========

The examples below give introductions to the framework and the utilities provided in this package. 

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   auto_examples/01_basic_mann_parameters_fit

.. raw:: html

    <hr>

.. toctree::
   :maxdepth: 1

   auto_examples/02_eddy-lifetime_fit
    
.. raw:: html

    <hr>


.. toctree::
   :maxdepth: 1
   

   auto_examples/03_eddy-lifetime_fit_3term_loss

.. raw:: html

    <hr>

.. toctree::
   :maxdepth: 1
   

   auto_examples/04_eddy-lifetime_fit_gelu

.. raw:: html

    <hr>


.. toctree::
   :maxdepth: 1

   auto_examples/05_custom_noisy_data_fit

.. raw:: html

    <hr>


.. toctree::
   :maxdepth: 1
   

   auto_examples/06_custom_data_interpolate_and_fit

.. raw:: html

    <hr>


.. toctree::
   :maxdepth: 1

   auto_examples/07_mann_linear_regression

.. raw:: html

    <hr>
   

.. toctree::
   :maxdepth: 1
   
   auto_examples/08_mann_box_generation_IEC

.. raw:: html

    <hr>

.. toctree::
   :maxdepth: 1

   auto_examples/09_drd_box

.. raw:: html

    <hr>